<script id="services.workload.images.details.template" type="text/x-handlebars-template">
    <div class="list-group" id="services.workload.images.details">
        <div class="list-group" id="services.workload.images.view">
            <div class="list-group">
                <div class="row list-group-item active"></div>

                {{#each items}}
                    <div class="row list-group-item" id="services.workload.images">
                        {{ this }}
                    </div>
                {{/each}}
            </div>
        </div>
    </div>
</script>