<!-- aad policies -->
<script id="services.aad.policies.partial" type="text/x-handlebars-template">
    <div id="resource-name" class="list-group-item active">
        <h4 class="list-group-item-heading">{{name}}</h4>
    </div>
    <div class="list-group-item">
        <h4 class="list-group-item-heading">Information</h4>
        <div class="list-group-item-text item-margin">Name: <span id="aad.policies.authorizationPolicy.name"><samp>{{value_or_none name}}</samp></span></div>
        <div class="list-group-item-text item-margin">Allow Invites From: <span id="aad.policies.{{@key}}.allow_invites_from"><samp>{{value_or_none allow_invites_from}}</samp></span></div>
        <div class="list-group-item-text item-margin">Allowed To Create Apps: <span id="aad.policies.{{@key}}.allowed_to_create_apps"><samp>{{convert_bool_to_enabled allowed_to_create_apps}}</samp></span></div>
        <div class="list-group-item-text item-margin">Allowed To Create Security Groups: <span id="aad.policies.{{@key}}.allowed_to_create_security_groups">{{convert_bool_to_enabled allowed_to_create_security_groups}}</span></div>
        <div class="list-group-item-text item-margin">Allowed To Read Other Users: <span id="aad.policies.{{@key}}.allowed_to_read_other_users"><samp>{{convert_bool_to_enabled allowed_to_read_other_users}}</samp></span></div>
        <div class="list-group-item-text item-margin">Allow Email Verified Users To Join Organization: <span id="aad.policies.{{@key}}.allow_email_verified_users_to_join_organization">{{convert_bool_to_enabled allow_email_verified_users_to_join_organization}}</span></div>
    </div>
</script>

<script>
    Handlebars.registerPartial("services.aad.policies", $("#services\\.aad\\.policies\\.partial").html());
</script>

<!-- Single aad group template -->
<script id="single_aad_policy-template" type="text/x-handlebars-template">
    {{> modal-template template='services.aad.policies'}}
</script>
<script>
    var single_aad_policy_template = Handlebars.compile($("#single_aad_policy-template").html());
</script>