
<!-- dynamodb tables -->
<script id="services.dynamodb.regions.id.tables.partial" type="text/x-handlebars-template">
    <div id="resource-name" class="list-group-item active">
        <h4 class="list-group-item-heading">{{name}}</h4>
    </div>
    <div class="list-group-item">
        <h4 class="list-group-item-heading">Information</h4>
        <div class="list-group-item-text item-margin">ID: <span id="dynamodb.regions.{{region}}.tables.{{@key}}.id"><samp>{{value_or_none id}}</samp></span></div>
        <div class="list-group-item-text item-margin">ARN: <span id="dynamodb.regions.{{region}}.tables.{{@key}}.arn"><samp>{{value_or_none arn}}</samp></span></div>
        <div class="list-group-item-text item-margin">Status: <span id="dynamodb.regions.{{region}}.tables.{{@key}}.table_status"><samp>{{value_or_none table_status}}</samp></span></div>
        <div class="list-group-item-text item-margin">Creation Date: <span id="dynamodb.regions.{{region}}.tables.{{@key}}.creation_date_time"><samp>{{format_date creation_date_time}}</samp></span></div>
        <div class="list-group-item-text item-margin">Automatic Backups: <span id="dynamodb.regions.{{region}}.tables.{{@key}}.automatic_backups_enabled">{{convert_bool_to_enabled automatic_backups_enabled}}</span></div>
        <div class="list-group-item-text item-margin">Item Count: <span id="dynamodb.regions.{{region}}.tables.{{@key}}.item_count"><samp>{{value_or_none item_count}}</samp></span></div>
    </div>
    {{#if tags}}
    <div class="list-group-item">
        <h4>Tags</h4>
        <ul>
            {{#each tags}}
            <li class="list-group-item-text"><samp>{{Key}}</samp>: <samp>{{Value}}</samp></li>
            {{/each}}
        </ul>
    </div>
    {{/if}}
</script>

<script>
    Handlebars.registerPartial("services.dynamodb.regions.id.tables", $("#services\\.dynamodb\\.regions\\.id\\.tables\\.partial").html());
</script>

<!-- Single dynamodb table template -->
<script id="single_dynamodb_table-template" type="text/x-handlebars-template">
    {{> modal-template template='services.dynamodb.regions.id.tables'}}
</script>
<script>
    var single_dynamodb_table_template = Handlebars.compile($("#single_dynamodb_table-template").html());
</script>
