
    <!-- elb ELB partial -->
    <script id="services.elb.regions.vpcs.elbs.linked_resources.partial" type="text/x-handlebars-template">
        <div class="accordion">
          {{#if resources.length}}
          <h5 class="list-group-item-heading accordion-heading">{{makeTitle resource_type}}:
            {{> count_badge count=resources.length target=(concat '#services' service 'regions' region 'vpcs' vpc 'elbs' @key resource_type)}}
          </h5>
          <div id="services.{{service}}.regions.{{region}}.vpcs.{{vpc}}.elbs.{{@key}}.{{resource_type}}" class="accordion-body">
            <div class="accordion-inner">
              <ul>
              {{#each resources}}
                <li class="list-group-item-text"><a href="javascript:showObject('services.{{../service}}.regions.{{../region}}.vpcs.{{../vpc}}.{{../resource_type}}.{{this}}')">{{this}}</a></li>
              {{/each}}
              </ul>
            </div>
          </div>
          {{else}}
            <h5 class="list-group-item-heading accordion-heading">{{makeTitle resource_type}}
                <span class="badge float-right">{{resources.length}}</span>
            </h5>
          {{/if}}
        </div>
    </script>
    <script>
        Handlebars.registerPartial("services.elb.regions.vpcs.elbs.linked_resources", $("#services\\.elb\\.regions\\.vpcs\\.elbs\\.linked_resources\\.partial").html());
    </script>
