<!-- networking domains -->
<script id="services.networking.domains.partial" type="text/x-handlebars-template">
    <div id="resource-name" class="list-group-item active">
        <h4 class="list-group-item-heading">{{name}}</h4>
    </div>
    <div class="list-group-item">
        <h4 class="list-group-item-heading">Information</h4>
        <div class="list-group-item-text item-margin">Id: <span id="networking.domains.{{@key}}.name"><samp>{{value_or_none name}}</samp></span></div>    
        <div class="list-group-item-text item-margin">Spf Record: <span id="networking.domains.{{@key}}.spf_record"><samp>{{value_or_none spf_record}}</samp></span></div>
        <div class="list-group-item-text item-margin">Dmarc Record: <span id="networking.domains.{{@key}}.dmarc_record"><samp>{{value_or_none dmarc_record}}</samp></span></div>
        <div class="list-group-item-text item-margin">Dkim Record: <span id="networking.domains.{{@key}}.dkim_record"><samp>{{value_or_none dkim_record}}</samp></span></div>
        <div class="list-group-item-text item-margin">Spf Record [+/~]all: <span id="networking.domains.{{@key}}.spf_record_all"><samp>{{value_or_none spf_record_all}}</samp></span></div>
        <div class="list-group-item-text item-margin">HighTTl Records (>3600s): <span id="networking.domains.{{@key}}.highttl_records"><samp>{{value_or_none highttl_records}}</samp></span></div>
    </div>
</script>

<script>
    Handlebars.registerPartial("services.networking.domains", $("#services\\.networking\\.domains\\.partial").html());
</script>

<!-- Single networking damain template -->
<script id="single_networking_damain-template" type="text/x-handlebars-template">
    {{> modal-template template='services.networking.domains'}}
</script>
<script>
    var single_networking_damain_template = Handlebars.compile($("#single_networking_damain-template").html());
</script>