<!-- securitycenter compliance_results -->
<script id="services.securitycenter.subscriptions.id.compliance_results.partial" type="text/x-handlebars-template">
    <div id="resource-name" class="list-group-item active">
        <h4 class="list-group-item-heading">{{name}}</h4>
    </div>
    <div class="list-group-item">
        <h4 class="list-group-item-heading">Information</h4>
        <div class="list-group-item-text item-margin">Name: <span id="securitycenter.subscriptions.{{subscription}}.compliance_results.{{@key}}.name"><samp>{{value_or_none name}}</samp></span></div>
        <div class="list-group-item-text item-margin">Resource Status: <span id="securitycenter.subscriptions.{{subscription}}.compliance_results.{{@key}}.resource_status"><samp>{{value_or_none resource_status}}</samp></span></div>
    </div>
</script>

<script>
    Handlebars.registerPartial("services.securitycenter.subscriptions.id.compliance_results", $("#services\\.securitycenter\\.subscriptions\\.id\\.compliance_results\\.partial").html());
</script>

<!-- Single securitycenter compliance_result template -->
<script id="single_securitycenter_compliance_result-template" type="text/x-handlebars-template">
    {{> modal-template template='services.securitycenter.subscriptions.id.compliance_results'}}
</script>
<script>
    var single_securitycenter_compliance_result_template = Handlebars.compile($("#single_securitycenter_compliance_result-template").html());
</script>
