<!-- vpc flow_logs -->
<script id="services.vpc.regions.id.flow_logs.partial" type="text/x-handlebars-template">
    <div id="resource-name" class="list-group-item active">
        <h4 class="list-group-item-heading">{{name}}</h4>
    </div>
    <div class="list-group-item">
        <h4 class="list-group-item-heading">Information</h4>
        <div class="list-group-item-text item-margin">Name: <span id="vpc.regions.{{region}}.flow_logs.{{@key}}.name"><samp>{{value_or_none name}}</samp></span></div>
        <div class="list-group-item-text item-margin">Resource ID: <span id="vpc.regions.{{region}}.flow_logs.{{@key}}.resource_id"><samp>{{value_or_none resource_id}}</samp></span></div>
        <div class="list-group-item-text item-margin">ARN: <span id="vpc.regions.{{region}}.flow_logs.{{@key}}.arn"><samp>{{value_or_none arn}}</samp></span></div>
        <div class="list-group-item-text item-margin">Creation Time: <span id="vpc.regions.{{region}}.flow_logs.{{@key}}.creation_time"><samp>{{format_date creation_time}}</samp></span></div>
        <div class="list-group-item-text item-margin">Flow Log Status: <span id="vpc.regions.{{region}}.flow_logs.{{@key}}.flow_log_status"><samp>{{value_or_none flow_log_status}}</samp></span></div>
        <div class="list-group-item-text item-margin">Deliver Logs Status: <span id="vpc.regions.{{region}}.flow_logs.{{@key}}.deliver_logs_status"><samp>{{value_or_none deliver_logs_status}}</samp></span></div>
        <div class="list-group-item-text item-margin">Deliver Logs Error Message: <span id="vpc.regions.{{region}}.flow_logs.{{@key}}.deliver_logs_error_message"><samp>{{value_or_none deliver_logs_error_message}}</samp></span></div>
        <div class="list-group-item-text item-margin">Traffic Type: <span id="vpc.regions.{{region}}.flow_logs.{{@key}}.traffic_type"><samp>{{value_or_none traffic_type}}</samp></span></div>
        <div class="list-group-item-text item-margin">Log Destination Type: <span id="vpc.regions.{{region}}.flow_logs.{{@key}}.log_destination_type"><samp>{{value_or_none log_destination_type}}</samp></span></div>
        <div class="list-group-item-text item-margin">Log Destination: <span id="vpc.regions.{{region}}.flow_logs.{{@key}}.log_destination"><samp>{{value_or_none log_destination}}</samp></span></div>
        <div class="list-group-item-text item-margin">Log Format: <span id="vpc.regions.{{region}}.flow_logs.{{@key}}.log_format"><samp>{{value_or_none log_format}}</samp></span></div>
        <div class="list-group-item-text item-margin">Max Aggregation Interval: <span id="vpc.regions.{{region}}.flow_logs.{{@key}}.max_aggregation_interval"><samp>{{value_or_none max_aggregation_interval}}</samp></span></div>
    </div>
    {{#if tags}}
    <div class="list-group-item">
        <h4>Tags</h4>
        <ul>
            {{#each tags}}
            <li class="list-group-item-text"><samp>{{Key}}</samp>: <samp>{{Value}}</samp></li>
            {{/each}}
        </ul>
    </div>
    {{/if}}
</script>

<script>
    Handlebars.registerPartial("services.vpc.regions.id.flow_logs", $("#services\\.vpc\\.regions\\.id\\.flow_logs\\.partial").html());
</script>

<!-- Single vpc flow_log template -->
<script id="single_vpc_flow_log-template" type="text/x-handlebars-template">
    {{> modal-template template='services.vpc.regions.id.flow_logs'}}
</script>
<script>
    var single_vpc_flow_log_template = Handlebars.compile($("#single_vpc_flow_log-template").html());
</script>
