<!-- stackdrivermonitoring alert_policies -->
<script id="services.stackdrivermonitoring.projects.id.alert_policies.partial" type="text/x-handlebars-template">
    <div id="resource-name" class="list-group-item active">
        <h4 class="list-group-item-heading">{{name}}</h4>
    </div>
    <div class="list-group-item">
        <h4 class="list-group-item-heading">Information</h4>
        <div class="list-group-item-text item-margin">Name: <span id="stackdrivermonitoring.projects.{{project}}.alert_policies.{{@key}}.name"><samp>{{value_or_none name}}</samp></span></div>
        <div class="list-group-item-text item-margin">Creation Record: <span id="stackdrivermonitoring.projects.{{project}}.alert_policies.{{@key}}.creation_record"><code>{{value_or_none creation_record}}</code></span></div>
        <div class="list-group-item-text item-margin">Mutation Record: <span id="stackdrivermonitoring.projects.{{project}}.alert_policies.{{@key}}.mutation_record"><code>{{value_or_none mutation_record}}</code></span></div>
        <div class="list-group-item-text item-margin">Conditions: <span id="stackdrivermonitoring.projects.{{project}}.alert_policies.{{@key}}.conditions"><code>{{value_or_none conditions}}</code></span></div>
        <div class="list-group-item-text item-margin">Combiner: <span id="stackdrivermonitoring.projects.{{project}}.alert_policies.{{@key}}.combiner"><samp>{{value_or_none combiner}}</samp></span></div>
        <div class="list-group-item-text item-margin">Enabled: <span id="stackdrivermonitoring.projects.{{project}}.alert_policies.{{@key}}.enabled"><samp>{{value_or_none enabled}}</samp></span></div>
    </div>
</script>

<script>
    Handlebars.registerPartial("services.stackdrivermonitoring.projects.id.alert_policies", $("#services\\.stackdrivermonitoring\\.projects\\.id\\.alert_policies\\.partial").html());
</script>

<!-- Single stackdrivermonitoring alert_policie template -->
<script id="single_stackdrivermonitoring_alert_policie-template" type="text/x-handlebars-template">
    {{> modal-template template='services.stackdrivermonitoring.projects.id.alert_policies'}}
</script>
<script>
    var single_stackdrivermonitoring_alert_policie_template = Handlebars.compile($("#single_stackdrivermonitoring_alert_policie-template").html());
</script>
