<!-- networking load_balancers -->
<script id="services.networking.load_balancers.partial" type="text/x-handlebars-template">
    <div id="resource-name" class="list-group-item active">
        <h4 class="list-group-item-heading">{{name}}</h4>
    </div>
    <div class="list-group-item">
        <h4 class="list-group-item-heading">Information</h4>
        <div class="list-group-item-text item-margin">Id: <span id="networking.load_balancers.{{@key}}.id"><samp>{{value_or_none id}}</samp></span></div>
        <div class="list-group-item-text item-margin">Name: <span id="networking.load_balancers.{{@key}}.name"><samp>{{value_or_none name}}</samp></span></div>
        <div class="list-group-item-text item-margin">Redirect HTTP To HTTPS: <span id="networking.load_balancers.{{@key}}.redirect_http_to_https"><samp>{{value_or_none redirect_http_to_https}}</samp></span></div>
        <div class="list-group-item-text item-margin">Enable Backend Keepalive: <span id="networking.load_balancers.{{@key}}.enable_backend_keepalive"><samp>{{value_or_none enable_backend_keepalive}}</samp></span></div>
        <div class="list-group-item-text item-margin">Droplets: <span id="networking.load_balancers.{{@key}}.droplet_ids"><samp>{{value_or_none droplet_ids}}</samp></span></div>
    </div>
</script>

<script>
    Handlebars.registerPartial("services.networking.load_balancers", $("#services\\.networking\\.load_balancers\\.partial").html());
</script>

<!-- Single networking load_balancer template -->
<script id="single_networking_load_balancer-template" type="text/x-handlebars-template">
    {{> modal-template template='services.networking.load_balancers'}}
</script>
<script>
    var single_networking_load_balancer_template = Handlebars.compile($("#single_networking_load_balancer-template").html());
</script>