<!-- cloudwatch metric_filters -->
<script id="services.cloudwatch.regions.id.metric_filters.partial" type="text/x-handlebars-template">
    <div id="resource-name" class="list-group-item active">
        <h4 class="list-group-item-heading">{{name}}</h4>
    </div>
    <div class="list-group-item">
        <h4 class="list-group-item-heading">Information</h4>
        <div class="list-group-item-text item-margin">Name: <span id="cloudwatch.regions.{{region}}.metric_filters.{{@key}}.name"><samp>{{value_or_none name}}</samp></span></div>
        <div class="list-group-item-text item-margin">ARN: <span id="cloudwatch.regions.{{region}}.metric_filters.{{@key}}.arn"><code>{{value_or_none arn}}</code></span></div>
        <div class="list-group-item-text item-margin">Creation Time: <span id="cloudwatch.regions.{{region}}.metric_filters.{{@key}}.creation_time">{{format_date creation_time}}</span></div>
        <div class="list-group-item-text item-margin">Log Group Name: <span id="cloudwatch.regions.{{region}}.metric_filters.{{@key}}.log_group_name"><samp>{{value_or_none log_group_name}}</samp></span></div>
        <div class="list-group-item-text item-margin">Pattern: <span id="cloudwatch.regions.{{region}}.metric_filters.{{@key}}.pattern"><code>{{value_or_none pattern}}</code></span></div>
    </div>
</script>

<script>
    Handlebars.registerPartial("services.cloudwatch.regions.id.metric_filters", $("#services\\.cloudwatch\\.regions\\.id\\.metric_filters\\.partial").html());
</script>

<!-- Single cloudwatch metric_filter template -->
<script id="single_cloudwatch_metric_filter-template" type="text/x-handlebars-template">
    {{> modal-template template='services.cloudwatch.regions.id.metric_filters'}}
</script>
<script>
    var single_cloudwatch_metric_filter_template = Handlebars.compile($("#single_cloudwatch_metric_filter-template").html());
</script>